@@ -16,6 +16,7 @@ pub struct Attribute {
     pub format: Option<String>,
     pub unit: Option<String>,
     pub entry_codes: Option<EntryCodes>,
+    pub sai: Option<String>,
 }
 
 pub struct AttributeBuilder {
@@ -34,6 +35,7 @@ impl AttributeBuilder {
                 format: None,
                 unit: None,
                 entry_codes: None,
+                sai: None,
             },
         }
     }
@@ -48,6 +50,11 @@ impl AttributeBuilder {
         self
     }
 
+    pub fn add_sai(mut self, sai: String) -> AttributeBuilder {
+        self.attribute.sai = Some(sai);
+        self
+    }
+
     pub fn add_format(mut self, format: String) -> AttributeBuilder {
         self.attribute.format = Some(format);
         self
