@@ -520,9 +520,18 @@ mod tests {
             .add_format("DD/MM/YYYY".to_string())
             .build();
 
+        let attr3 = AttributeBuilder::new(String::from("n3"), AttributeType::Sai)
+            .add_sai("sai".to_string())
+            .add_label(hashmap! {
+                "En".to_string() => "Reference: ".to_string(),
+                "Pl".to_string() => "Referecja: ".to_string(),
+            })
+            .build();
+
         let oca = oca_builder
             .add_attribute(attr1)
             .add_attribute(attr2)
+            .add_attribute(attr3)
             .finalize();
 
         // println!(
@@ -530,7 +539,11 @@ mod tests {
         //     serde_json::to_string_pretty(&serde_json::to_value(&oca).unwrap()).unwrap()
         // );
 
-        assert_eq!(oca.capture_base.attributes.len(), 2);
+        assert_eq!(
+            oca.capture_base.attributes.get(&"n3".to_string()),
+            Some(&"SAI:sai".to_string())
+        );
+        assert_eq!(oca.capture_base.attributes.len(), 3);
         assert_eq!(oca.capture_base.pii.len(), 1);
     }
 }
