@@ -1,7 +1,8 @@
 use maplit::hashmap;
 use oca_rust::state::{
-    attribute::{AttributeBuilder, AttributeType, Entry},
+    attribute::{AttributeBuilder, AttributeType, Entries, Entry},
     encoding::Encoding,
+    entry_codes::EntryCodes,
     oca::OCABuilder,
     validator::Validator,
 };
@@ -40,7 +41,11 @@ fn create_oca() {
             "en_EN".to_string() => "Gender: ".to_string(),
             "pl_PL".to_string() => "Płeć: ".to_string(),
         })
-        .add_entries(vec![
+        .add_entry_codes(EntryCodes::Array(vec![
+            "male".to_string(),
+            "female".to_string(),
+        ]))
+        .add_entries(Entries::Object(vec![
             Entry::new(
                 "male".to_string(),
                 hashmap! {
@@ -55,7 +60,7 @@ fn create_oca() {
                     "pl_PL".to_string() => "Kobieta".to_string(),
                 },
             ),
-        ])
+        ]))
         .build();
 
     let oca = oca_builder
